==> kubernetes-model-certificates-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/certificates/v1beta1/CertificateSigningRequestStatusFluent.java <==
package io.fabric8.kubernetes.api.model.certificates.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CertificateSigningRequestStatusFluent<A extends io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getCertificate();
  public A withCertificate(java.lang.String certificate);
  public java.lang.Boolean hasCertificate();
  
  /**
   * Method is deprecated. use withCertificate instead.
   */
  @java.lang.Deprecated
  public A withNewCertificate(java.lang.String arg0);
  public A addToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> getConditions();
  public java.util.List<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> buildConditions();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildFirstCondition();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildLastCondition();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition... conditions);
  public java.lang.Boolean hasConditions();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionFluent<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> kubernetes-model-certificates-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/certificates/v1beta1/CertificateSigningRequestStatusFluent.java <==
package io.fabric8.kubernetes.api.model.certificates.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CertificateSigningRequestStatusFluent<A extends io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getCertificate();
  public A withCertificate(java.lang.String certificate);
  public java.lang.Boolean hasCertificate();
  
  /**
   * Method is deprecated. use withCertificate instead.
   */
  @java.lang.Deprecated
  public A withNewCertificate(java.lang.String arg0);
  public A addToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> getConditions();
  public java.util.List<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> buildConditions();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildFirstCondition();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildLastCondition();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition... conditions);
  public java.lang.Boolean hasConditions();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionFluent<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
